import { EventCategory, EventOrganizer } from "@/lib/event";

import styles from "./eventFilter.module.scss";

export const EventFilter = ({
  eventCategories,
  setCategory,
  activeCategory,
  eventOrganizers,
  setOrganizer,
  activeOrganizer,
}: {
  eventCategories: EventCategory[];
  setCategory: (slug: string | null) => void;
  activeCategory: string | null;
  eventOrganizers: EventOrganizer[];
  setOrganizer: (slug: string | null) => void;
  activeOrganizer: string | null;
}) => {
  const onOrganizerSelect = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const organizer = e.target.value;
    setOrganizer(organizer === "" ? null : organizer);
  };

  return (
    <div className={styles.eventFilter}>
      <span className="suphead">Kategori</span>
      <ul>
        {eventCategories
          .filter((x) => x.showInFilters)
          .map((category) => (
            <li
              key={category.slug}
              className={activeCategory === category.slug ? styles.active : ""}
            >
              <button
                onClick={() =>
                  setCategory(
                    activeCategory === category.slug ? null : category.slug
                  )
                }
              >
                {category.name}
              </button>
            </li>
          ))}
      </ul>
      <label htmlFor="organizer" className="suphead">
        Arrangør
      </label>
      <div>
        <select
          name="organizer"
          value={activeOrganizer ?? ""}
          onChange={onOrganizerSelect}
        >
          <option value="">Vis alle</option>
          {eventOrganizers.map((organizer) => (
            <option key={organizer.slug} value={organizer.slug}>
              {organizer.name}
            </option>
          ))}
        </select>
      </div>
    </div>
  );
};
